@@ -1,13 +1,13 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef FILTERBALSA_H
-#define FILTERBALSA_H
+#pragma once
 
 #include "filters.h"
+#include <memory>
 namespace MailImporter
 {
 class FilterBalsaPrivate;
@@ -33,8 +33,7 @@ private:
     void processDirectory(const QString &path);
 
     MailImporter::MessageStatus statusFromFile(const QString &filename);
-    FilterBalsaPrivate *const d;
+    std::unique_ptr<FilterBalsaPrivate> const d;
 };
 }
 
-#endif // FILTERBALSA_H
