@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef FilterSeaMonkey_H
-#define FilterSeaMonkey_H
+#pragma once
 
 #include "filterthunderbird.h"
 namespace MailImporter
@@ -28,4 +27,3 @@ protected:
 };
 }
 
-#endif // FilterSeaMonkey_H
