@@ -2,13 +2,12 @@
   filterthunderbird.h  -  Thunderbird mail import
 
   SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILIMPORTER_FILTER_THUNDERBIRD_H
-#define MAILIMPORTER_FILTER_THUNDERBIRD_H
+#pragma once
 
 #include "filters.h"
 
@@ -44,4 +43,3 @@ private:
 };
 }
 
-#endif
